@@ -4,6 +4,10 @@ from typing import List
 import fitz
 from fitz import Pixmap
 
+__all__ = [
+    'pdf_to_png',
+]
+
 
 def pdf_to_png(data: bytes) -> List[bytes]:
     result = []
